# Generated by Django 5.0.6 on 2024-10-17 18:48
from django.contrib.postgres.operations import TrigramExtension
from django.contrib.postgres.search import SearchVector
from django.db import migrations


def compute_search_vector(apps, schema_editor):
    # RunPython to populate the initial search_vector values
    UserProfile = apps.get_model("common", "UserProfile")
    for profile in UserProfile.objects.all():
        id = profile.user.id
        user_email = profile.user.email
        first_name = profile.person.first_name
        last_name = profile.person.last_name
        search_vector = SearchVector(id, user_email, first_name, last_name)
        profile.search_vector = search_vector
        profile.save()


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0001_initial"),
    ]

    operations = [
        # Ensure the PostgreSQL extension is available
        TrigramExtension(),
        migrations.RunPython(
            code=compute_search_vector,
            reverse_code=migrations.RunPython.noop,
        ),
        migrations.RunSQL(
            sql="""
            CREATE OR REPLACE FUNCTION update_search_vector_trigger_function()
            RETURNS TRIGGER AS $$
            BEGIN
                NEW.search_vector :=
                    to_tsvector('pg_catalog.english',
                                COALESCE((SELECT id FROM accountx_user WHERE id = NEW.user_id), 1) || ' ' ||
                                COALESCE((SELECT email FROM accountx_user WHERE id = NEW.user_id), '') || ' ' ||
                                COALESCE((SELECT first_name FROM common_person WHERE id = NEW.person_id), '') || ' ' ||
                                COALESCE((SELECT last_name FROM common_person WHERE id = NEW.person_id), ''));
                RETURN NEW;
            END;
            $$ LANGUAGE plpgsql;

            CREATE TRIGGER update_search_vector_trigger
            BEFORE INSERT OR UPDATE OF user_id, person_id
            ON common_userprofile
            FOR EACH ROW
            EXECUTE FUNCTION update_search_vector_trigger_function();
            """
        ),
    ]
